==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/registration/RegistryClient.java <==
/*
 * Copyright (c) 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Jan 9, 2009
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.registration;

import org.oasisOpen.docs.wsrf.sg2.AddDocument;
import org.oasisOpen.docs.wsrf.sg2.AddResponseDocument;
import org.oasisOpen.docs.wsrf.sg2.AddDocument.Add;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

import pl.edu.icm.unicore.uvos.util.Configuration;

import de.fzj.unicore.wsrflite.xfire.WSRFClientFactory;
import de.fzj.unicore.wsrflite.xmlbeans.client.BaseWSRFClient;
import de.fzj.unicore.wsrflite.xmlbeans.sg.ServiceGroupRegistration;

/**
 * Trivial impl of registry client
 * @author golbi
 */
public class RegistryClient extends BaseWSRFClient
{
	public RegistryClient(String registryURL, Configuration config) throws Exception
	{
		super(registryURL, createEpr(registryURL), getClientFactory(config));
	}

	private static WSRFClientFactory getClientFactory(Configuration cfg)
	{
		return new WSRFClientFactory(new ClientSecurityConfiguration(cfg));
	}
	
	private static EndpointReferenceType createEpr(String url)
	{
		EndpointReferenceType ret = EndpointReferenceType.Factory.newInstance();
		ret.addNewAddress().setStringValue(url);
		return ret;
	}
	
	public AddResponseDocument addRegistryEntry(EndpointReferenceType serviceEPR) throws Exception
	{
		AddDocument argDoc = AddDocument.Factory.newInstance();
		Add arg = argDoc.addNewAdd();
		arg.setMemberEPR(serviceEPR);		
		ServiceGroupRegistration proxy = makeProxy(ServiceGroupRegistration.class);
		AddResponseDocument res = proxy.Add(argDoc);
		return res;
	}
}

==> unicore-uvos-server-1.6.0-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/registration/RegistryClient.java <==
/*
 * Copyright (c) 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Jan 9, 2009
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.registration;

import org.oasisOpen.docs.wsrf.sg2.AddDocument;
import org.oasisOpen.docs.wsrf.sg2.AddResponseDocument;
import org.oasisOpen.docs.wsrf.sg2.AddDocument.Add;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;

import de.fzj.unicore.wsrflite.xfire.WSRFClientFactory;
import de.fzj.unicore.wsrflite.xmlbeans.client.BaseWSRFClient;
import de.fzj.unicore.wsrflite.xmlbeans.sg.ServiceGroupRegistration;

/**
 * Trivial impl of registry client
 * @author golbi
 */
public class RegistryClient extends BaseWSRFClient
{
	public RegistryClient(String registryURL, UVOSServerProperties config) throws Exception
	{
		super(registryURL, createEpr(registryURL), getClientFactory(config));
	}

	private static WSRFClientFactory getClientFactory(UVOSServerProperties cfg)
	{
		return new WSRFClientFactory(cfg.getClientConfiguration());
	}
	
	private static EndpointReferenceType createEpr(String url)
	{
		EndpointReferenceType ret = EndpointReferenceType.Factory.newInstance();
		ret.addNewAddress().setStringValue(url);
		return ret;
	}
	
	public AddResponseDocument addRegistryEntry(EndpointReferenceType serviceEPR) throws Exception
	{
		AddDocument argDoc = AddDocument.Factory.newInstance();
		Add arg = argDoc.addNewAdd();
		arg.setMemberEPR(serviceEPR);		
		ServiceGroupRegistration proxy = makeProxy(ServiceGroupRegistration.class);
		AddResponseDocument res = proxy.Add(argDoc);
		return res;
	}
}
